Class: Google::Apis::PolicysimulatorV1alpha::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayCustomConstraintOverlay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1alpha/classes.rb,
lib/google/apis/policysimulator_v1alpha/representations.rb,
lib/google/apis/policysimulator_v1alpha/representations.rb

Overview

A change to an OrgPolicy custom constraint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayCustomConstraintOverlay

Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayCustomConstraintOverlay.



684
685
686
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 684

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_constraintGoogle::Apis::PolicysimulatorV1alpha::GoogleCloudOrgpolicyV2CustomConstraint

A custom constraint defined by customers which can only be applied to the given resource types and organization. By creating a custom constraint, customers can apply policies of this custom constraint. Creating a custom constraint itself does NOT apply any policy enforcement. Corresponds to the JSON property customConstraint



676
677
678
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 676

def custom_constraint
  @custom_constraint
end

#custom_constraint_parentString

Optional. Resource the constraint is attached to. Example: "organization/ 987654" Corresponds to the JSON property customConstraintParent

Returns:

  • (String)


682
683
684
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 682

def custom_constraint_parent
  @custom_constraint_parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



689
690
691
692
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 689

def update!(**args)
  @custom_constraint = args[:custom_constraint] if args.key?(:custom_constraint)
  @custom_constraint_parent = args[:custom_constraint_parent] if args.key?(:custom_constraint_parent)
end