Class: Google::Apis::PolicysimulatorV1alpha::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1alpha/classes.rb,
lib/google/apis/policysimulator_v1alpha/representations.rb,
lib/google/apis/policysimulator_v1alpha/representations.rb

Overview

A change to an OrgPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay

Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay.



711
712
713
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 711

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policyGoogle::Apis::PolicysimulatorV1alpha::GoogleCloudOrgpolicyV2Policy

Defines an organization policy that is used to specify constraints for configurations of Google Cloud resources. Corresponds to the JSON property policy



703
704
705
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 703

def policy
  @policy
end

#policy_parentString

Optional. The parent of the policy we are attaching to. Example: "projects/ 123456" Corresponds to the JSON property policyParent

Returns:

  • (String)


709
710
711
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 709

def policy_parent
  @policy_parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



716
717
718
719
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 716

def update!(**args)
  @policy = args[:policy] if args.key?(:policy)
  @policy_parent = args[:policy_parent] if args.key?(:policy_parent)
end