Class: Google::Apis::PolicysimulatorV1alpha::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1alpha::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1alpha/classes.rb,
lib/google/apis/policysimulator_v1alpha/representations.rb,
lib/google/apis/policysimulator_v1alpha/representations.rb
Overview
OrgPolicyViolationsPreview is a resource providing a preview of the violations that will exist if an OrgPolicy change is made. The list of violations are modeled as child resources and retrieved via a ListOrgPolicyViolations API call. There are potentially more OrgPolicyViolations than could fit in an embedded field. Thus, the use of a child resource instead of a field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_constraints ⇒ Array<String>
Output only.
-
#name ⇒ String
Output only.
-
#overlay ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay
The proposed changes to OrgPolicy.
-
#resource_counts ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts
A summary of the state of all resources scanned for compliance with the changed OrgPolicy.
-
#state ⇒ String
Output only.
-
#violations_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview
constructor
A new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview
Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview.
781 782 783 |
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when this OrgPolicyViolationsPreview was created.
Corresponds to the JSON property createTime
733 734 735 |
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 733 def create_time @create_time end |
#custom_constraints ⇒ Array<String>
Output only. The names of the constraints against which all
OrgPolicyViolations were evaluated. If OrgPolicyOverlay only contains
PolicyOverlay then it contains the name of the configured custom constraint,
applicable to the specified policies. Otherwise it contains the name of the
constraint specified in CustomConstraintOverlay. Format: organizations/
organization_id/customConstraints/custom_constraint_id`Example:
organizations/123/customConstraints/custom.createOnlyE2TypeVms
Corresponds to the JSON propertycustomConstraints`
744 745 746 |
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 744 def custom_constraints @custom_constraints end |
#name ⇒ String
Output only. The resource name of the OrgPolicyViolationsPreview. It has the
following format: organizations/organization/locations/location/
orgPolicyViolationsPreviews/orgPolicyViolationsPreview`Example:
organizations/my-example-org/locations/global/orgPolicyViolationsPreviews/
506a5f7f
Corresponds to the JSON propertyname`
753 754 755 |
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 753 def name @name end |
#overlay ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay
The proposed changes to OrgPolicy.
Corresponds to the JSON property overlay
758 759 760 |
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 758 def @overlay end |
#resource_counts ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts
A summary of the state of all resources scanned for compliance with the
changed OrgPolicy.
Corresponds to the JSON property resourceCounts
764 765 766 |
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 764 def resource_counts @resource_counts end |
#state ⇒ String
Output only. The state of the OrgPolicyViolationsPreview.
Corresponds to the JSON property state
769 770 771 |
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 769 def state @state end |
#violations_count ⇒ Fixnum
Output only. The number of OrgPolicyViolations in this
OrgPolicyViolationsPreview. This count may differ from resource_summary.
noncompliant_count because each OrgPolicyViolation is specific to a resource *
and* constraint. If there are multiple constraints being evaluated (i.e.
multiple policies in the overlay), a single resource may violate multiple
constraints.
Corresponds to the JSON property violationsCount
779 780 781 |
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 779 def violations_count @violations_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
786 787 788 789 790 791 792 793 794 |
# File 'lib/google/apis/policysimulator_v1alpha/classes.rb', line 786 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_constraints = args[:custom_constraints] if args.key?(:custom_constraints) @name = args[:name] if args.key?(:name) @overlay = args[:overlay] if args.key?(:overlay) @resource_counts = args[:resource_counts] if args.key?(:resource_counts) @state = args[:state] if args.key?(:state) @violations_count = args[:violations_count] if args.key?(:violations_count) end |