Class: Google::Apis::PolicysimulatorV1alpha::PolicySimulatorService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::PolicysimulatorV1alpha::PolicySimulatorService
- Defined in:
- lib/google/apis/policysimulator_v1alpha/service.rb
Overview
Policy Simulator API
Policy Simulator is a collection of endpoints for creating, running, and
viewing a Replay. A Replay is a type of simulation that lets you see how
your members' access to resources might change if you changed your IAM policy.
During a Replay, Policy Simulator re-evaluates, or replays, past access
attempts under both the current policy and your proposed policy, and compares
those results to determine how your members' access might change under the
proposed policy.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://policysimulator.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#get_folder_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_folder_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_folder_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_organization_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_organization_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_organization_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#initialize ⇒ PolicySimulatorService
constructor
A new instance of PolicySimulatorService.
-
#list_folder_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
Constructor Details
#initialize ⇒ PolicySimulatorService
Returns a new instance of PolicySimulatorService.
53 54 55 56 57 58 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 53 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-policysimulator_v1alpha', client_version: Google::Apis::PolicysimulatorV1alpha::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
46 47 48 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 46 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
51 52 53 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 51 def quota_user @quota_user end |
Instance Method Details
#get_folder_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
81 82 83 84 85 86 87 88 89 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 81 def get_folder_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
112 113 114 115 116 117 118 119 120 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 112 def get_folder_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
143 144 145 146 147 148 149 150 151 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 143 def get_folder_location_replay_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
223 224 225 226 227 228 229 230 231 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 223 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
303 304 305 306 307 308 309 310 311 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 303 def get_organization_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
334 335 336 337 338 339 340 341 342 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 334 def get_organization_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
365 366 367 368 369 370 371 372 373 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 365 def get_organization_location_replay_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
445 446 447 448 449 450 451 452 453 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 445 def get_project_location_access_policy_simulation_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
476 477 478 479 480 481 482 483 484 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 476 def get_project_location_org_policy_violations_preview_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_replay_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
507 508 509 510 511 512 513 514 515 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 507 def get_project_location_replay_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_folder_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 188 def list_folder_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 268 def list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 410 def list_organization_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
552 553 554 555 556 557 558 559 560 561 562 563 564 |
# File 'lib/google/apis/policysimulator_v1alpha/service.rb', line 552 def list_project_location_replay_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/{+name}', ) command.response_representation = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::PolicysimulatorV1alpha::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |